==> oneChannelGUI_1.6.5.tar.gz: oneChannelGUI/R/helpmenu.R <==
#set of functions, directly/indirectly involved, in oneChannelGUI helpMenu
#oneChannelGUI siggenesHelp
#oneChannelGUI
#oneChannelGUI changes gives info on the latest updates on oneChannelGUI 
################################################################################

affyPLMHelp <- function()
{
	Try(affyPLMHelpIndex <- file.path(system.file("doc",package="affyPLM"),"index.html"))
	Try(browseURL(affyPLMHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening affyPLM help...\nIf nothing happens, please open :\n",affyPLMHelpIndex,"\nyourself.",sep="")))
}
################################################################################

pdmclassHelp <- function()
{
	Try(pdmclassHelpIndex <- file.path(system.file("doc",package="pdmclass"),"index.html"))
	Try(browseURL(pdmclassHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening pdmclass help...\nIf nothing happens, please open :\n",pdmclassHelpIndex,"\nyourself.",sep="")))
}
################################################################################

pamrHelp <- function()
{
	Try(pamrHelpIndex <- file.path(system.file("doc",package="pamr"),"index.html"))
	Try(browseURL(pamrHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening pamr help...\nIf nothing happens, please open :\n",pamrHelpIndex,"\nyourself.",sep="")))
}
################################################################################

ssizeHelp <- function()
{
	Try(ssizeHelpIndex <- file.path(system.file("doc",package="ssize"),"index.html"))
	Try(browseURL(ssizeHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening ssize help...\nIf nothing happens, please open :\n",ssizeHelpIndex,"\nyourself.",sep="")))
}
################################################################################

sizepowerHelp <- function()
{
	Try(sizepowerHelpIndex <- file.path(system.file("doc",package="sizepower"),"index.html"))
	Try(browseURL(sizepowerHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening sizepower help...\nIf nothing happens, please open :\n",sizepowerHelpIndex,"\nyourself.",sep="")))
}
################################################################################

genefilterHelp <- function()
{
	Try(genefilterHelpIndex <- file.path(system.file("doc",package="genefilter"),"index.html"))
	Try(browseURL(genefilterHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening genefilter help...\nIf nothing happens, please open :\n",genefilterHelpIndex,"\nyourself.",sep="")))
}
################################################################################

siggenesHelp <- function()
{
	Try(siggenesHelpIndex <- file.path(system.file("doc",package="siggenes"),"index.html"))
	Try(browseURL(siggenesHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening siggenes help...\nIf nothing happens, please open :\n",siggenesHelpIndex,"\nyourself.",sep="")))
}
################################################################################

GOstatsHelp <- function()
{
	Try(GOstatsHelpIndex <- file.path(system.file("doc",package="GOstats"),"index.html"))
	Try(browseURL(GOstatsHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening GOstats help...\nIf nothing happens, please open :\n",GOstatsHelpIndex,"\nyourself.",sep="")))
}
################################################################################

maSigProHelp <- function()
{
	Try(maSigProHelpIndex <- file.path(system.file("doc",package="maSigPro"),"index.html"))
	Try(browseURL(maSigProHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening maSigPro help...\nIf nothing happens, please open :\n",maSigProHelpIndex,"\nyourself.",sep="")))
}
################################################################################

RankProdHelp <- function()
{
	Try(RankProdHelpIndex <- file.path(system.file("doc",package="RankProd"),"index.html"))
	Try(browseURL(RankProdHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening RankProd help...\nIf nothing happens, please open :\n",RankProdHelpIndex,"\nyourself.",sep="")))
}
################################################################################

oneChannelGUIHelp <- function()
{
	Try(oneChannelGUIHelpIndex <- file.path(system.file("doc",package="oneChannelGUI"),"index.html"))
	Try(browseURL(oneChannelGUIHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening oneChannelGUI help...\nIf nothing happens, please open :\n",oneChannelGUIHelpIndex,"\nyourself.",sep="")))
}
################################################################################

"AboutaffylmGUI" <- function()
{
    Try(tkmessageBox(title="About affylmGUI",message=paste("Basic affylmGUI ", getPackageVersion("affylmGUI") , ", Wettenhall et al. Bioinformatics 2004, 22:897-899, ",
                              ", using limma Version ",getPackageVersion("limma"),".  The limma package was developed by Gordon Smyth and the Graphical User Interface (GUI) was developed by James Wettenhall.",sep=""),type="ok",icon="info"))
}

################################################################################

"AboutextendedaffylmGUI" <- function()
{
    Try(tkmessageBox(title=paste("About oneChannelGUI ", getPackageVersion("oneChannelGUI"), sep=""),message=paste("Basic affylmGUI ", getPackageVersion("affylmGUI") , ", originally designed by James Wettenhall and Ken Simpson, was extended by Raffaele A. Calogero ",
                              ", using limma Version ",getPackageVersion("limma"),".  The limma package was developed by Gordon Smyth and the Graphical User Interface (GUI) was developed by James Wettenhall.",sep=""),type="ok",icon="info"))
}

################################################################################

"changes" <- function(){
         Try(cat("\nLatest major changes in oneChannelGUI:\n"))
         Try(cat("\n1.4.3 Direct uploading of Affymetrix library files.\n"))
         Try(cat("\n1.4.4 Gene 1.0 ST analysis is implemented.\n"))
         Try(cat("\n1.4.4 Gene, Exon gene-level annotation updated to:\n"))
         Try(cat("\n\thuex10stv2na24hg18"))
         Try(cat("\n\tmoex10stv1na24mm8"))
         Try(cat("\n\traex10stv1na24rn4"))
         Try(cat("\n\thugene10stv1na24hg18"))
         Try(cat("\n\tmogene10stv1na24mm8"))
         Try(cat("\n\tragene10stv1na24rn4\n"))
         Try(cat("\n1.4.5 Ingenuity template A generation for exon arrays\n"))
         Try(cat("\n1.4.5 Exon exon-level annotation updated to:\n"))
         Try(cat("\n\tcrosshybhuex10stv2na24hg18"))
         Try(cat("\n\tcrosshybmoex10stv1na24mm8"))
         Try(cat("\n\tcrosshybraex10stv1na24rn4"))
         Try(cat("\n1.4.6 Illumina data analysis:"))
         Try(cat("\n\tILLUMINA data loading from BeadStudio v1/2 outputs."))
         Try(cat("\n\tThe .readBead is a modification of readBead function from BeadExplorer package.")) 
         Try(cat("\n1.6.1 updating genechips EXON 1.0 analysis:"))
         Try(cat("\n\tFunction Filtering by EGs list uses org.XX.eg.db."))
         Try(cat("\n\tFunction Attaching ACC and Entrez Gene IDs to Probe set IDs (EXON 1.0 ST) uses org.XX.eg.db"))
         Try(cat("\n\tFunction Identifying enriched GO terms uses org.XX.eg.db"))
         Try(cat("\n\tFunction Extracting Affy IDs linked to an enriched GO term uses org.XX.eg.db"))
         Try(cat("\n1.6.3 Extending exon-level genechips EXON 1.0 analysis:"))
         Try(cat("\n\t The function Mapping exon level probe sets to EG exons \n\tcreates a table that links, via biomaRt, the target exon-level probeset sequence \n\tonto the exon sequence of ENSEMBL gene."))
         Try(cat("\n\tThe function Open as been modified to update the affylibs and apt dir location into the \n\taffylmGUIenvironment."))
         Try(cat("\n1.6.4 oneChannelGUI internal annotation for Gene and Exon chips can be \nupdated by the user using a function \navailable in the General Tools menu."))
         Try(cat("\n1.6.4 Extending exon-level genechips EXON 1.0 analysis:"))
         Try(cat("\n\t......"))
         #gathering affy libs and apt tools folders
         Try(netaffxUpdates  <- paste(.path.package("oneChannelGUI", quiet = FALSE), "/etc/netaffxUpdates.txt", sep=""))
         Try(cat("\nNetaffx library files were updated from user on:\n"))
         Try(cat(readLines(netaffxUpdates), sep="\n"))
}

==> oneChannelGUI_1.8.10.tar.gz: oneChannelGUI/R/helpmenu.R <==
#set of functions, directly/indirectly involved, in oneChannelGUI helpMenu
#oneChannelGUI siggenesHelp
#oneChannelGUI
#oneChannelGUI changes gives info on the latest updates on oneChannelGUI 
################################################################################

affyPLMHelp <- function()
{
	Try(affyPLMHelpIndex <- file.path(system.file("doc",package="affyPLM"),"index.html"))
	Try(browseURL(affyPLMHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening affyPLM help...\nIf nothing happens, please open :\n",affyPLMHelpIndex,"\nyourself.",sep="")))
}
################################################################################

pdmclassHelp <- function()
{
	Try(pdmclassHelpIndex <- file.path(system.file("doc",package="pdmclass"),"index.html"))
	Try(browseURL(pdmclassHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening pdmclass help...\nIf nothing happens, please open :\n",pdmclassHelpIndex,"\nyourself.",sep="")))
}
################################################################################

pamrHelp <- function()
{
	Try(pamrHelpIndex <- file.path(system.file("doc",package="pamr"),"index.html"))
	Try(browseURL(pamrHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening pamr help...\nIf nothing happens, please open :\n",pamrHelpIndex,"\nyourself.",sep="")))
}
################################################################################

ssizeHelp <- function()
{
	Try(ssizeHelpIndex <- file.path(system.file("doc",package="ssize"),"index.html"))
	Try(browseURL(ssizeHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening ssize help...\nIf nothing happens, please open :\n",ssizeHelpIndex,"\nyourself.",sep="")))
}
################################################################################

sizepowerHelp <- function()
{
	Try(sizepowerHelpIndex <- file.path(system.file("doc",package="sizepower"),"index.html"))
	Try(browseURL(sizepowerHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening sizepower help...\nIf nothing happens, please open :\n",sizepowerHelpIndex,"\nyourself.",sep="")))
}
################################################################################

genefilterHelp <- function()
{
	Try(genefilterHelpIndex <- file.path(system.file("doc",package="genefilter"),"index.html"))
	Try(browseURL(genefilterHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening genefilter help...\nIf nothing happens, please open :\n",genefilterHelpIndex,"\nyourself.",sep="")))
}
################################################################################

siggenesHelp <- function()
{
	Try(siggenesHelpIndex <- file.path(system.file("doc",package="siggenes"),"index.html"))
	Try(browseURL(siggenesHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening siggenes help...\nIf nothing happens, please open :\n",siggenesHelpIndex,"\nyourself.",sep="")))
}
################################################################################

GOstatsHelp <- function()
{
	Try(GOstatsHelpIndex <- file.path(system.file("doc",package="GOstats"),"index.html"))
	Try(browseURL(GOstatsHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening GOstats help...\nIf nothing happens, please open :\n",GOstatsHelpIndex,"\nyourself.",sep="")))
}
################################################################################

maSigProHelp <- function()
{
	Try(maSigProHelpIndex <- file.path(system.file("doc",package="maSigPro"),"index.html"))
	Try(browseURL(maSigProHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening maSigPro help...\nIf nothing happens, please open :\n",maSigProHelpIndex,"\nyourself.",sep="")))
}
################################################################################

RankProdHelp <- function()
{
	Try(RankProdHelpIndex <- file.path(system.file("doc",package="RankProd"),"index.html"))
	Try(browseURL(RankProdHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening RankProd help...\nIf nothing happens, please open :\n",RankProdHelpIndex,"\nyourself.",sep="")))
}
################################################################################

oneChannelGUIHelp <- function()
{
	Try(oneChannelGUIHelpIndex <- file.path(system.file("doc",package="oneChannelGUI"),"index.html"))
	Try(browseURL(oneChannelGUIHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening oneChannelGUI help...\nIf nothing happens, please open :\n",oneChannelGUIHelpIndex,"\nyourself.",sep="")))
}
################################################################################

"AboutaffylmGUI" <- function()
{
    Try(tkmessageBox(title="About affylmGUI",message=paste("Basic affylmGUI ", getPackageVersion("affylmGUI") , ", Wettenhall et al. Bioinformatics 2004, 22:897-899, ",
                              ", using limma Version ",getPackageVersion("limma"),".  The limma package was developed by Gordon Smyth and the Graphical User Interface (GUI) was developed by James Wettenhall.",sep=""),type="ok",icon="info"))
}

################################################################################

"AboutextendedaffylmGUI" <- function()
{
    Try(tkmessageBox(title=paste("About oneChannelGUI ", getPackageVersion("oneChannelGUI"), sep=""),message=paste("Basic affylmGUI ", getPackageVersion("affylmGUI") , ", originally designed by James Wettenhall and Ken Simpson, was extended by Raffaele A. Calogero ",
                              ", using limma Version ",getPackageVersion("limma"),".  The limma package was developed by Gordon Smyth and the Graphical User Interface (GUI) was developed by James Wettenhall.",sep=""),type="ok",icon="info"))
}

################################################################################

"changes" <- function(){
         Try(cat("\nLatest major changes in oneChannelGUI:\n"))
         Try(cat("\n1.4.3 Direct uploading of Affymetrix library files.\n"))
         Try(cat("\n1.4.4 Gene 1.0 ST analysis is implemented.\n"))
         Try(cat("\n1.4.4 Gene, Exon gene-level annotation updated to:\n"))
         Try(cat("\n\thuex10stv2na24hg18"))
         Try(cat("\n\tmoex10stv1na24mm8"))
         Try(cat("\n\traex10stv1na24rn4"))
         Try(cat("\n\thugene10stv1na24hg18"))
         Try(cat("\n\tmogene10stv1na24mm8"))
         Try(cat("\n\tragene10stv1na24rn4\n"))
         Try(cat("\n1.4.5 Ingenuity template A generation for exon arrays\n"))
         Try(cat("\n1.4.5 Exon exon-level annotation updated to:\n"))
         Try(cat("\n\tcrosshybhuex10stv2na24hg18"))
         Try(cat("\n\tcrosshybmoex10stv1na24mm8"))
         Try(cat("\n\tcrosshybraex10stv1na24rn4"))
         Try(cat("\n1.4.6 Illumina data analysis:"))
         Try(cat("\n\tILLUMINA data loading from BeadStudio v1/2 outputs."))
         Try(cat("\n\tThe .readBead is a modification of readBead function from BeadExplorer package.")) 
         Try(cat("\n1.6.1 updating genechips EXON 1.0 analysis:"))
         Try(cat("\n\tFunction Filtering by EGs list uses org.XX.eg.db."))
         Try(cat("\n\tFunction Attaching ACC and Entrez Gene IDs to Probe set IDs (EXON 1.0 ST) uses org.XX.eg.db"))
         Try(cat("\n\tFunction Identifying enriched GO terms uses org.XX.eg.db"))
         Try(cat("\n\tFunction Extracting Affy IDs linked to an enriched GO term uses org.XX.eg.db"))
         Try(cat("\n1.6.3 Extending exon-level genechips EXON 1.0 analysis:"))
         Try(cat("\n\t The function Mapping exon level probe sets to EG exons \n\tcreates a table that links, via biomaRt, the target exon-level probeset sequence \n\tonto the exon sequence of ENSEMBL gene."))
         Try(cat("\n\tThe function Open as been modified to update the affylibs and apt dir location into the \n\taffylmGUIenvironment."))
         Try(cat("\n1.6.4 oneChannelGUI internal annotation for Gene and Exon chips can be \nupdated by the user using a function \navailable in the General Tools menu."))
         Try(cat("\n1.6.5 Updating Illumina annotation to illuminaXXXXvXProbeID.db"))
         Try(cat("\n1.6.5 Extending Illumina annotation to Rank Product analysis"))
         Try(cat("\n1.6.5 Updating Affymetrix 3'IVT annotation to XXXX.db"))
         Try(cat("\n1.6.5 Extending exon-level genechips EXON 1.0 analysis:"))
         Try(cat("\n\tRemapping of exon-level PSR on RefSeq via BLASTN for detected Alternative Splicing Events."))
         Try(cat("\n\tRefSeqs fasta files are downloaded in apt tool dir during apt tool folder definition."))
         Try(cat("\n\tPlatform specific BLAST executable must be manually installed by user in the blast subdir in apt tool folder."))
         Try(cat("\n\tThe function Mapping exon level probe sets to the corresponding exon generates a fasta file with PSR and target exon sequences."))
         Try(cat("\n1.8.6 Optimizing exon-level genechips EXON 1.0 analysis:"))
         Try(cat("\n\tExon-level filters now produce a file with the list of significantly detected exons."))
         Try(cat("\n\tGraphs associated to alternative splicing inspection were simplified."))
         Try(cat("\n\tThe function Mapping exon-level probesets to RefSeq now uses \n\ta list of exons considered significantly alternatively spliced."))
         Try(cat("\n1.8.7 Bioconductor update function:"))
         Try(cat("\n\tIn the general menu is now available a function to update all bioconductor libraries on the fly\n."))
         Try(cat("\n1.8.8 Bioconductor BeadStudion V3:"))
         Try(cat("\n\treport generated by BeadStudio V3 can be loaded in oneChannelGUI\n."))
         Try(cat("\n\tBeadStudio V3 report MUST be a GROUP PROBE PROFILE containing the following fields:\n"))
         Try(cat("\n\t\tColumns:\n"))
         Try(cat("\n\t\tProbeId\n"))
         Try(cat("\n\t\tXXXXXXX_A\n"))
         Try(cat("\n\t\t.........\n"))
         Try(cat("\n\t\tXXXXXXX_F\n"))
         Try(cat("\n\t\t\tSubcolumns:\n"))
         Try(cat("\n\t\t\tAVG_Signal\n"))
         Try(cat("\n\t\t\tAvg_NBEADS\n"))
         Try(cat("\n\t\t\tDetection Pval\n."))
         Try(cat("\n1.8.9 Bioconductor:"))
         Try(cat("\n\tfast parameter in GCRMA is set to FALSE\n."))
         #gathering affy libs and apt tools folders
         Try(netaffxUpdates  <- paste(.path.package("oneChannelGUI", quiet = FALSE), "/etc/netaffxUpdates.txt", sep=""))
         Try(cat("\nNetaffx library files were updated from user on:\n"))
         Try(cat(readLines(netaffxUpdates), sep="\n"))
}
